aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorOliver Smith <osmith@sysmocom.de>2021-04-29 09:52:20 +0200
committerOliver Smith <osmith@sysmocom.de>2021-04-29 11:03:07 +0200
commit3c31513bccb687108423913d0c8bc320d8f21c70 (patch)
treedada141153251f6d5807d20fdcbad3aefc8bb1b6
parent57a07962f6b85be6c7e0c312d3f36aa2c3bc4920 (diff)
OBS: nightly: build: simplify changelog parameter
-rwxr-xr-xscripts/osmocom-nightly-packages.sh8
1 files changed, 2 insertions, 6 deletions
diff --git a/scripts/osmocom-nightly-packages.sh b/scripts/osmocom-nightly-packages.sh
index a51ef55..86f406e 100755
--- a/scripts/osmocom-nightly-packages.sh
+++ b/scripts/osmocom-nightly-packages.sh
@@ -114,7 +114,7 @@ checkout() {
# Generate a source package and upload it to OBS
# $1: package name (e.g. "libosmocore")
# $2: update debian dir when set to "commit" (default):
# * add dependency on osmocom-$FEED package
# * add new version to changelog (e.g. "1.5.1.96.c96d7.202104281354")
# $3: arguments to pass to "gbp buildpackage"
@@ -126,10 +126,6 @@ build() {
local oscdir=$REPO/osc/$PROJ/$name
local dependver="$OSMO_OBS_CONFLICT_PKGVER"
- if [ -z "$changelog" ] ; then
- changelog=commit
- fi
-
if [ -d "$oscdir" ] ; then
# remove earlier version
cd "$oscdir"
@@ -143,7 +139,7 @@ build() {
cd "$repodir"
- if [ "$changelog" = "commit" ] ; then
+ if [ "$changelog" != "no_commit" ] ; then
# Add date to increase version even if commit did not change (OS#5135)
VER="$(get_commit_version).$DT"
osmo_obs_add_depend_deb "./debian/control" "$name" "osmocom-$FEED" "$dependver"
@@ -114,7 +114,7 @@ checkout() {
# Generate a source package and upload it to OBS
# $1: package name (e.g. "libosmocore")
-# $2: update debian dir when set to "commit" (default):
+# $2: update debian dir, unless set to "no_commit":
# * add dependency on osmocom-$FEED package
# * add new version to changelog (e.g. "1.5.1.96.c96d7.202104281354")